CallRequestCreateResponse class

Constructors

CallRequestCreateResponse({required String requestId, required String userId, required String status, required int position, required int etaSeconds, required String token, required CsnSupportRequestType? requestType})
CallRequestCreateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

etaSeconds int
final
hashCode int
The hash code for this object.
no setterinherited
position int
final
requestId String
final
requestType CsnSupportRequestType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
token String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited