ConsumerResponse class

Constructors

ConsumerResponse({required String id, required String producerId, required String kind, required Map<String, dynamic> rtpParameters, String? codec})
ConsumerResponse.fromJson(Map<String, dynamic> json)
factory

Properties

codec String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
kind String
final
producerId String
final
rtpParameters Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited