CsnThemeData class

Inheritance
Annotations

Constructors

CsnThemeData({required Color primary, required Color accent, required Color background, required Color surface, required Color text, required Color mutedText, required Color success, required Color warning, required Color danger})
const
CsnThemeData.dark()
factory
CsnThemeData.light()
factory

Properties

accent Color
final
background Color
final
danger Color
final
hashCode int
The hash code for this object.
no setterinherited
mutedText Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success Color
final
surface Color
final
text Color
final
type Object
The extension's type.
no setterinherited
warning Color
final

Methods

copyWith({Color? primary, Color? accent, Color? background, Color? surface, Color? text, Color? mutedText, Color? success, Color? warning, Color? danger}) CsnThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CsnThemeData>? other, double t) ThemeExtension<CsnThemeData>
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited